﻿using System;
using System.Collections.Generic;
using System.Linq;
using HarmonyLib;
using RimWorld;
using UnityEngine;
using Verse;

namespace Reorderer.Engine
{
	// Token: 0x02000006 RID: 6
	public static class DesignationCategoryConfig
	{
		// Token: 0x06000010 RID: 16 RVA: 0x000023E4 File Offset: 0x000005E4
		public static void Init()
		{
			DesignationCategoryConfig.CheckDefStates();
			DesignationCategoryConfig._orderer = new OrderGUI<DesignationCategoryDef>(() => Settings.DesignationCategoryStates, new Action(DesignationCategoryConfig.ApplyChanges), new Action(DesignationCategoryConfig.Reset));
		}

		// Token: 0x06000011 RID: 17 RVA: 0x00002437 File Offset: 0x00000637
		public static void OnGUI(Rect rect)
		{
			DesignationCategoryConfig._orderer.OnGUI(rect, false);
		}

		// Token: 0x06000012 RID: 18 RVA: 0x00002448 File Offset: 0x00000648
		private static void CheckDefStates()
		{
			if (DesignationCategoryConfig._originals == null)
			{
				DesignationCategoryConfig._originals = new Dictionary<DesignationCategoryDef, int>();
				foreach (DesignationCategoryDef designationCategoryDef in DefDatabase<DesignationCategoryDef>.AllDefs)
				{
					DesignationCategoryConfig._originals[designationCategoryDef] = designationCategoryDef.order;
				}
			}
			if (Settings.DesignationCategoryStates == null)
			{
				Settings.DesignationCategoryStates = new List<DefState<DesignationCategoryDef>>();
			}
			using (IEnumerator<DesignationCategoryDef> enumerator = (from def in DefDatabase<DesignationCategoryDef>.AllDefs
			orderby def.order descending
			select def).GetEnumerator())
			{
				while (enumerator.MoveNext())
				{
					DesignationCategoryDef def = enumerator.Current;
					if (!Settings.DesignationCategoryStates.Any((DefState<DesignationCategoryDef> p) => p.Def == def))
					{
						Settings.DesignationCategoryStates.Add(new DefState<DesignationCategoryDef>(def, true));
					}
				}
			}
			DesignationCategoryConfig.ApplyChanges();
		}

		// Token: 0x06000013 RID: 19 RVA: 0x00002558 File Offset: 0x00000758
		private static void Reset()
		{
			foreach (KeyValuePair<DesignationCategoryDef, int> keyValuePair in DesignationCategoryConfig._originals)
			{
				keyValuePair.Key.order = keyValuePair.Value;
			}
			Settings.DesignationCategoryStates = new List<DefState<DesignationCategoryDef>>();
			DesignationCategoryConfig.CheckDefStates();
		}

		// Token: 0x06000014 RID: 20 RVA: 0x000025C8 File Offset: 0x000007C8
		private static void ApplyChanges()
		{
			int num = Settings.DesignationCategoryStates.Count - 1;
			foreach (DefState<DesignationCategoryDef> defState in Settings.DesignationCategoryStates)
			{
				defState.Def.order = num;
				num--;
			}
			Traverse.Create(MainButtonDefOf.Architect.TabWindow).Method("CacheDesPanels", Array.Empty<object>()).GetValue();
			Settings.Save();
		}

		// Token: 0x04000009 RID: 9
		private static OrderGUI<DesignationCategoryDef> _orderer;

		// Token: 0x0400000A RID: 10
		private static Dictionary<DesignationCategoryDef, int> _originals;
	}
}
