﻿using System;
using System.Collections.Generic;
using System.Linq;
using HarmonyLib;
using RimWorld;
using UnityEngine;
using Verse;

namespace Reorderer.Engine
{
	// Token: 0x02000008 RID: 8
	public static class MainButtonsConfig
	{
		// Token: 0x17000003 RID: 3
		// (get) Token: 0x06000019 RID: 25 RVA: 0x000026D0 File Offset: 0x000008D0
		// (set) Token: 0x0600001A RID: 26 RVA: 0x000026D7 File Offset: 0x000008D7
		public static bool IsReady { get; private set; }

		// Token: 0x0600001B RID: 27 RVA: 0x000026E0 File Offset: 0x000008E0
		public static void Init(MainButtonsRoot instance)
		{
			Settings.Validate();
			DesignationCategoryConfig.Init();
			MainButtonsConfig._buttonOrder = Traverse.Create(instance).Field("allButtonsInOrder");
			MainButtonsConfig.CheckDefStates();
			MainButtonsConfig._orderer = new OrderGUI<MainButtonDef>(() => Settings.MainButtonStates, new Action(MainButtonsConfig.ApplyChanges), new Action(MainButtonsConfig.Reset));
			MainButtonsConfig.IsReady = true;
		}

		// Token: 0x0600001C RID: 28 RVA: 0x00002758 File Offset: 0x00000958
		public static void OnGUI(Rect rect)
		{
			MainButtonsConfig._orderer.OnGUI(rect, true);
		}

		// Token: 0x0600001D RID: 29 RVA: 0x00002768 File Offset: 0x00000968
		private static void CheckDefStates()
		{
			if (Settings.MainButtonStates == null)
			{
				Settings.MainButtonStates = new List<DefState<MainButtonDef>>();
			}
			using (IEnumerator<MainButtonDef> enumerator = (from def in DefDatabase<MainButtonDef>.AllDefs
			orderby def.order
			select def).GetEnumerator())
			{
				while (enumerator.MoveNext())
				{
					MainButtonDef def = enumerator.Current;
					if (def.buttonVisible && !Settings.MainButtonStates.Any((DefState<MainButtonDef> state) => state.Def == def))
					{
						Settings.MainButtonStates.Add(new DefState<MainButtonDef>(def, true));
					}
				}
			}
			MainButtonsConfig.ApplyChanges();
		}

		// Token: 0x0600001E RID: 30 RVA: 0x00002830 File Offset: 0x00000A30
		private static void Reset()
		{
			Settings.MainButtonStates = new List<DefState<MainButtonDef>>();
			MainButtonsConfig.CheckDefStates();
		}

		// Token: 0x0600001F RID: 31 RVA: 0x00002844 File Offset: 0x00000A44
		private static void ApplyChanges()
		{
			Settings.MainButtonStates = (from state in Settings.MainButtonStates
			orderby state.Enabled descending
			select state).ToList<DefState<MainButtonDef>>();
			MainButtonsConfig._buttonOrder.SetValue((from state in Settings.MainButtonStates
			where state.Enabled
			select state.Def).ToList<MainButtonDef>());
			Settings.Save();
		}

		// Token: 0x0400000D RID: 13
		private static Traverse _buttonOrder;

		// Token: 0x0400000E RID: 14
		private static OrderGUI<MainButtonDef> _orderer;
	}
}
