﻿using System;
using System.Collections.Generic;
using UnityEngine;
using Verse;

namespace Reorderer.Engine
{
	// Token: 0x02000009 RID: 9
	public class OrderGUI<T> where T : Def, new()
	{
		// Token: 0x06000020 RID: 32 RVA: 0x000028E6 File Offset: 0x00000AE6
		public OrderGUI(Func<List<DefState<T>>> defStates, Action applyChanges, Action doReset)
		{
			this._defStates = defStates;
			this._applyChanges = applyChanges;
			this._doReset = doReset;
		}

		// Token: 0x06000021 RID: 33 RVA: 0x00002910 File Offset: 0x00000B10
		public void OnGUI(Rect rect, bool isCheckbox)
		{
			List<DefState<T>> list = this._defStates();
			float height = (float)list.Count * 48f + 8f;
			Rect rect2 = new Rect(0f, 0f, rect.width - 16f, height);
			Widgets.BeginScrollView(rect, ref this._scrollPosition, rect2, true);
			Rect rect3 = rect2.ContractedBy(4f);
			Listing_Standard listing_Standard = new Listing_Standard
			{
				ColumnWidth = 220f
			};
			listing_Standard.Begin(rect3);
			for(int num = 0; num < list.Count; num++)
			{
				this.DoRow(listing_Standard, isCheckbox, num, list.Count);
            }
			if (listing_Standard.ButtonText("Reorderer.Reset".Translate(), null))
			{
				this._doReset();
			}
			listing_Standard.End();
			Widgets.EndScrollView();
		}

		// Token: 0x06000022 RID: 34 RVA: 0x00002A1C File Offset: 0x00000C1C
		private void DoRow(Listing listing, bool isCheckbox, int index, int maxindex)
		{
            DefState<T> state = this._defStates()[index];
            Rect rect = listing.GetRect(48f);
            Widgets.BeginGroup(rect);
            Rect rect2 = new Rect(0f, 0f, 24f, 24f);
            if (index > 0)
            {
                if (Widgets.ButtonImage(rect2, TexButton.ReorderUp, Color.white, true))
                {
                    Log.Message("test");
                    this.Reorder(index, index-1);
                }
            }
            if (index < maxindex - 1)
            {
                Rect rect3 = new Rect(0f, 24f, 24f, 24f);
                if (Widgets.ButtonImage(rect3, TexButton.ReorderDown, Color.white, true))
                {
                    this.Reorder(index, index + 1);
                }
            }
            Rect rect4 = new Rect(24f, 0f, 180f, 48f);
            Widgets.DrawAtlas(rect4, Widgets.ButtonSubtleAtlas);
            if (isCheckbox)
			{
				bool enabled = state.Enabled;
				Widgets.CheckboxLabeled(rect4, state.Def.LabelCap, ref state.Enabled, false, null, null, false);
				if (state.Enabled != enabled)
				{
					this._applyChanges();
					return;
				}
			}
			else
			{
				Widgets.Label(rect4, state.Def.LabelCap);
			}
            Widgets.EndGroup();
        }

		// Token: 0x06000023 RID: 35 RVA: 0x00002AB8 File Offset: 0x00000CB8
		private void Reorder(int currentIndex, int newIndex)
		{
			if (currentIndex == newIndex)
			{
				return;
			}
			List<DefState<T>> list = this._defStates();
            DefState<T> temp = list[currentIndex];
            list[currentIndex] = list[newIndex];
            list[newIndex] = temp;
			this._applyChanges();
		}

		// Token: 0x04000010 RID: 16
		private Vector2 _scrollPosition = Vector2.zero;

		// Token: 0x04000011 RID: 17
		private readonly Func<List<DefState<T>>> _defStates;

		// Token: 0x04000012 RID: 18
		private readonly Action _applyChanges;

		// Token: 0x04000013 RID: 19
		private readonly Action _doReset;
	}
}
