﻿using System;
using System.Collections.Generic;
using System.Linq;
using Reorderer.Engine;
using Reorderer.Patch;
using RimWorld;
using UnityEngine;
using Verse;

namespace Reorderer
{
	// Token: 0x02000003 RID: 3
	public class Settings : ModSettings
	{
		// Token: 0x06000008 RID: 8 RVA: 0x000020B0 File Offset: 0x000002B0
		public static void Validate()
		{
			if (Settings._instance != null)
			{
				return;
			}
			Settings._instance = Reorderer.ReordererMod.Instance.GetSettings<Settings>();
			List<DefState<MainButtonDef>> mainButtonStates = Settings.MainButtonStates;
			List<DefState<MainButtonDef>> mainButtonStates2;
			if (mainButtonStates == null)
			{
				mainButtonStates2 = null;
			}
			else
			{
				mainButtonStates2 = (from state in mainButtonStates
				where state.Def != null && state.Def.buttonVisible
				select state).ToList<DefState<MainButtonDef>>();
			}
			Settings.MainButtonStates = mainButtonStates2;
			List<DefState<DesignationCategoryDef>> designationCategoryStates = Settings.DesignationCategoryStates;
			List<DefState<DesignationCategoryDef>> designationCategoryStates2;
			if (designationCategoryStates == null)
			{
				designationCategoryStates2 = null;
			}
			else
			{
				designationCategoryStates2 = (from state in designationCategoryStates
				where state.Def != null
				select state).ToList<DefState<DesignationCategoryDef>>();
			}
			Settings.DesignationCategoryStates = designationCategoryStates2;
			Settings.Save();
		}

		// Token: 0x06000009 RID: 9 RVA: 0x0000214D File Offset: 0x0000034D
		public static void Save()
		{
			Settings._instance.Write();
		}

		// Token: 0x0600000A RID: 10 RVA: 0x0000215C File Offset: 0x0000035C
		public static void OnGUI(Rect rect)
		{
			Rect[] hgrid = rect.GetHGrid(4f, new float[]
			{
				200f,
				-1f
			});
			Listing_Standard listing_Standard = new Listing_Standard();
			listing_Standard.Begin(MainButtonsConfig.IsReady ? hgrid[1] : rect);
			if (MainButtonsConfig.IsReady)
			{
				if (listing_Standard.RadioButton("Reorderer.MainButtons".Translate(), Settings._typeSelected == 0, 0f, null, null))
				{
					Settings._typeSelected = 0;
				}
				if (listing_Standard.RadioButton("Reorderer.DesignationCategories".Translate(), Settings._typeSelected == 1, 0f, null, null))
				{
					Settings._typeSelected = 1;
				}
			}
			else
			{
				listing_Standard.Label("Reorderer.NotReady".Translate(), -1f, null);
			}
			listing_Standard.NewColumn();
			listing_Standard.End();
			if (!MainButtonsConfig.IsReady)
			{
				return;
			}
			if (Settings._typeSelected == 0)
			{
				MainButtonsConfig.OnGUI(hgrid[2]);
				return;
			}
			if (Settings._typeSelected == 1)
			{
				DesignationCategoryConfig.OnGUI(hgrid[2]);
			}
		}

		// Token: 0x0600000B RID: 11 RVA: 0x0000226C File Offset: 0x0000046C
		public override void ExposeData()
		{
			Scribe_Collections.Look<DefState<MainButtonDef>>(ref Settings.MainButtonStates, "MainButtonStates", LookMode.Deep, Array.Empty<object>());
			Scribe_Collections.Look<DefState<DesignationCategoryDef>>(ref Settings.DesignationCategoryStates, "DesignationCategoryStates", LookMode.Deep, Array.Empty<object>());
			base.ExposeData();
		}

		// Token: 0x04000005 RID: 5
		private static Settings _instance;

		// Token: 0x04000006 RID: 6
		private static int _typeSelected;

		// Token: 0x04000007 RID: 7
		public static List<DefState<MainButtonDef>> MainButtonStates;

		// Token: 0x04000008 RID: 8
		public static List<DefState<DesignationCategoryDef>> DesignationCategoryStates;
	}
}
